/**************************************************************************
*  PIA_LIB.C - Contains the equates for the PIA and the delay() function. *
*                                                                         *
*  by YourName Here                                                       *
*  The Date Here                                                          *
**************************************************************************/

#define  PIADDRA  *(unsigned char *)0xB800   /* Data Direction Reg  A  */
#define  PIAPDRA  *(unsigned char *)0xB800   /* Peripheral Data Reg A  */
#define  PIACRA   *(unsigned char *)0xB801   /* Control Register A     */
#define  PIADDRB  *(unsigned char *)0xB802   /* Data Direction Reg  B  */
#define  PIAPDRB  *(unsigned char *)0xB802   /* Peripheral Data Reg B  */
#define  PIACRB   *(unsigned char *)0xB803   /* Control Register B     */


#define  OUTPUTS  0xFF
#define  INPUTS   0x00


/*
.-------------------------------------------------------------------------.
|  unsigned int delay(unsigned int ms);                                   |
|                                                                         |
|  Runs a software delay loop for the specified number of milli-seconds.  |
|  T (cycles) = 24 + 15 + ms*(41+35*33)                                   |
|                                                                         |
|  Inputs - ms is the required number of milliseconds.                    |
|  Return - returns the input parameter.                                  |
`-------------------------------------------------------------------------'
*/
unsigned int delay(unsigned int ms)
{
int count;                             /* [24] including call  */

while(ms)                              /* [13] evaluating ms   */
   {
   for(count=35; count; count--) ;     /* [11]; [16]; [17]     */
   ms--;                               /* [17] decrementing ms */
   }

return(ms);                            /* [15] returning code  */
}


#ifndef __TURBOC__

/*
.--------------------------------------------------------------------.
|  unsigned int delayasm(unsigned int ms);                           |
|                                                                    |
|  Runs a software delay loop for the specified number of milli-     |
|  seconds.  Similar to above except this one shows inline assembly. |
|  Note the two different commenting techniques available.  Also,    |
|  beware that the first column should be blank except for labels.   |
|  If you need access to a label defined in C, it should be preceded |
|  by and underscore.  Example:  asm(" bne _delayasm");              |
|                                                                    |
|  Inputs - ms is the required number of milliseconds.               |
|  Return - returns the input parameter.                             |
`--------------------------------------------------------------------'
*/
unsigned int delayasm(unsigned int ms)
{
asm("            ldx    2,x       ;     Get parameter from stack   ");
asm("delayasm_0: ldy    #174       ");  /* [ 4]                4    */
asm("delayasm_1: dey               ");  /* [ 4] \ 7 x 174 = 1218    */
asm("            bne    delayasm_1 ");  /* [ 3] /                   */
asm("            dex               ");  /* [ 3]                3    */
asm("            bne    delayasm_0 ");  /* [ 3]                3    */
                                        /*                  ----    */
                                        /*                  1228    */
                                        /* 1228 x 814ns = 0.999ms   */
return(ms);
}

#endif
